From mboxrd@z Thu Jan 1 00:00:00 1970 Return-Path: Received: (majordomo@vger.kernel.org) by vger.kernel.org via listexpand id S932145AbdKNXyC (ORCPT ); Tue, 14 Nov 2017 18:54:02 -0500 Received: from Galois.linutronix.de ([146.0.238.70]:39656 "EHLO Galois.linutronix.de" rhost-flags-OK-OK-OK-OK) by vger.kernel.org with ESMTP id S932073AbdKNXxw (ORCPT ); Tue, 14 Nov 2017 18:53:52 -0500 Date: Wed, 15 Nov 2017 00:53:24 +0100 (CET) From: Thomas Gleixner To: Linus Torvalds cc: "Rafael J. Wysocki" , WANG Chao , Linux Kernel Mailing List , Ingo Molnar , "H. Peter Anvin" , Vikas Shivappa , Kate Stewart , Len Brown , Greg Kroah-Hartman , Philippe Ombredanne , Mathias Krause , the arch/x86 maintainers , Linux PM , "Rafael J. Wysocki" Subject: Re: [PATCH] x86: use cpufreq_quick_get() for /proc/cpuinfo "cpu MHz" again In-Reply-To: Message-ID: References: <20171109103814.70688-1-chao.wang@ucloud.cn> <2101739.Je3pS2vcJU@aspire.rjw.lan> User-Agent: Alpine 2.20 (DEB 67 2015-01-07) MIME-Version: 1.0 Content-Type: text/plain; charset=US-ASCII X-Linutronix-Spam-Score: -1.0 X-Linutronix-Spam-Level: - X-Linutronix-Spam-Status: No , -1.0 points, 5.0 required, ALL_TRUSTED=-1,SHORTCIRCUIT=-0.0001 Sender: linux-kernel-owner@vger.kernel.org List-ID: X-Mailing-List: linux-kernel@vger.kernel.org On Tue, 14 Nov 2017, Linus Torvalds wrote: > On Tue, Nov 14, 2017 at 2:47 PM, Rafael J. Wysocki wrote: > > > > So what about the one below? It works for me as expected. > > Can somebody with 100+ cores test this? Ingo? You had a 160 core > machine that took forever, didn't you.. On a 144 CPUs machine: time cat /proc/cpuinfo >/dev/null Current head: real 0m0.003s user 0m0.000s sys 0m0.002s Current head + Raphaels patch: real 0m0.029s user 0m0.000s sys 0m0.010s So that patch is actually slower. Thanks, tglx